<?php

/***************************************************************
*
* Keyword-Plugin für moziloCMS.
* 
* Details: http://software.azett.com
* 
***************************************************************/

class MetaKeywords extends Plugin {

    function getContent($value) {
    
        // Aktuell vorhandene Inhaltsseiten einlesen
        if ($this->settings->get("initialize") == "true") {
            $this->initialize();
        }

        $keywords_as_properties = $this->getKeywordsAsProperties();
        $keywords = $this->getKeywordsForCurrentPage($keywords_as_properties);
	// Temp-Datei wieder leeren
        fopen("plugins/MetaKeywords/keywords.tmp", 'w');
        return $keywords;
    } // function getContent
    
    function getConfig() {
        $config = array();
        $config['keywords'] = array(
            "type" => "textarea",                       // Pflicht:  Eingabetyp 
            "cols" => "100",                             // Pflicht:  Spaltenanzahl 
            "rows" => "10",                              // Pflicht:  Zeilenanzahl
            "description" => "Meta-Keywords der einzelnen Inhaltsseiten<br />(Kategorie:Inhaltsseite&nbsp;=&nbsp;keyword1&nbsp;keyword2&nbsp;...)",                // Pflicht:  Beschreibung
            "regex" => "/^.+=.+$/"                      // optional: Erlaubte Werte als regulärer Ausdruck (hier: wenigstens ein Zeichen; wird beim Speichern der Einstellungen überprüft)
        );
        $config['initialize'] = array(
            "type" => "checkbox",
            "description" => "Inhaltsseiten neu einlesen <br />(vorhandene&nbsp;Werte&nbsp;bleiben&nbsp;erhalten)"
        );
        
        return $config;
    } // function getConfig
    
    function getInfo() {
            $info = array(
            // Plugin-Name + Version
            "<b>MetaKeywords</b> 1.2.2010-10-20",
            // moziloCMS-Version
            "1.12",
            // Kurzbeschreibung nur <span> und <br /> sind erlaubt
            "Eigene Meta-Keywords für jede Inhaltsseite",
            // Name des Autors
            "Arvid Zimmermann",
            // Download-URL
            "http://software.azett.com",
            // Platzhalter für die Selectbox in der Editieransicht 
            // - ist das Array leer, erscheint das Plugin nicht in der Selectbox
            array()
        );
        return $info;
    } // function getInfo
    
    // Hilfsfunktion: Textarea-Inhalt als Properties-Objekt zurückgeben
    function getKeywordsAsProperties() {
        $keywords_as_array = explode("<br />", $this->settings->get("keywords"));
        $keywords_as_properties = new Properties("plugins/MetaKeywords/keywords.tmp");
        foreach ($keywords_as_array as $currentline) {
            // Zeile am ersten "=" aufsplitten
            $equalpos = strpos($currentline, "=");
            if ($equalpos > 0) {
                $currentvalue = trim(substr($currentline, $equalpos+1, strlen($currentline)-$equalpos));
                $currentkey = trim(substr($currentline, 0, $equalpos));
            $keywords_as_properties->set($currentkey, $currentvalue);
            }
        }
        return $keywords_as_properties;
    }

    // Hilfsfunktion: Properties-Objekt in die Plugin-Settings speichern
    function setKeywordsFromProperties($keywords) {
        $keywords_as_array = $keywords->toArray();
        $keywords = "";
        foreach ($keywords_as_array as $currentkey => $currentvalue) {
            if ($currentkey != "readonly") {
                $keywords = $keywords . $currentkey . " = " . $currentvalue . "<br />";
            }
        }
        $this->settings->set("keywords", $keywords);
    }
    
    // Hilfsfunktion: Keywords für aktuelle Inhaltsseite zurückgeben
    function getKeywordsForCurrentPage($keywords_as_properties) {
        global $CAT_REQUEST;
        global $PAGE_REQUEST;
        global $specialchars;
        global $CMS_CONF;
        global $CatPage;
        
        $currentcat = $CatPage->get_HrefText($CAT_REQUEST, false);
        $currentpage = $CatPage->get_HrefText($CAT_REQUEST,$PAGE_REQUEST);
        if ($keywords_as_properties->keyExists($currentcat.":".$currentpage)) {
            $currentkeyword = $keywords_as_properties->get($currentcat.":".$currentpage);
            if ($currentkeyword != "") {
                return $currentkeyword;
            }
        }
        return $specialchars->rebuildSpecialChars($CMS_CONF->get("websitekeywords"),false,true);
    } 
    
    
    function initialize() {
        global $CatPage;
        
        $keywords_as_properties = $this->getKeywordsAsProperties();
        $changed = false;

        foreach ($CatPage->get_CatArray(false,false,array(EXT_PAGE,EXT_HIDDEN)) as $cat) {
            foreach ($CatPage->get_PageArray($cat,array(EXT_PAGE,EXT_HIDDEN),true) as $page) {
                $keyToCheck = $CatPage->get_HrefText($cat,false). ":" .$CatPage->get_HrefText($cat,$page);
                if (!$keywords_as_properties->keyExists($keyToCheck)) {
                    $keywords_as_properties->set($keyToCheck, "");
                    $changed = true;
                }
            }
        }
        if ($changed) {
            $this->setKeywordsFromProperties($keywords_as_properties);
        }
        $this->settings->set("initialize", "false");
    }
}

?>